@@ -23,17 +23,32 @@ class ChainedStore(BaseStore):
         if not stores:
             raise ValueError("you didn't specify any internal stores for this ChainedStore to operate on")
         self.__stores = stores
+        self.__reversed_stores = list(tuple(stores))
+        self.__reversed_stores.reverse()
+        
+        # set up deserializing per store
+        self.__deserialize_callbacks_per_store = {}
+        for i in range(0, len(stores)):
+            if hasattr(stores[i], "_before_stockpyle_deserialize"):
+                for previous_store in stores[0:i]:
+                    if not previous_store in self.__deserialize_callbacks_per_store:
+                        self.__deserialize_callbacks_per_store[previous_store] = []
+                    self.__deserialize_callbacks_per_store[previous_store].append(stores[i]._before_stockpyle_deserialize)
     
     def put(self, obj):
         
-        # write-through
-        for store in self.__stores:
+        # write-through (most-persistent to least-persistent)
+        # we do this because persistent stores may attach additional
+        # state upon put that the less-persistent stores need
+        for store in self.__reversed_stores:
             store.put(obj)
     
     def batch_put(self, objs):
         
-        # write-through
-        for store in self.__stores:
+        # write-through (most-persistent to least-persistent)
+        # we do this because persistent stores may attach additional
+        # state upon put that the less-persistent stores need
+        for store in self.__reversed_stores:
             store.batch_put(objs)
     
     def delete(self, obj):
@@ -57,6 +72,9 @@ class ChainedStore(BaseStore):
                 # we found it, pull it through all previous layers
                 for previous_store in self.__stores[0:i]:
                     previous_store.put(obj)
+                
+                # also, post-process the object
+                self.__run_deserialize_callbacks(self.__stores[i], obj)
                 return obj
         
         # never found it
@@ -81,7 +99,19 @@ class ChainedStore(BaseStore):
             # make sure any new objects are persisted in upper layers
             for previous_store in self.__stores[0:i]:
                 previous_store.batch_put(nonnull_new_objects)
+                
+            # also, post-process the new objects
+            for obj in nonnull_new_objects:
+                self.__run_deserialize_callbacks(self.__stores[i], obj)
         
         # return whichever objects we found
         return final_objects
-        
\ No newline at end of file
+    
+    def __run_deserialize_callbacks(self, store, obj):
+        """helper that runs any necessary deserialization callbacks
+        on the given object.  For example, the SqlAlchemyStore defines a
+        _before_stockpyle_deserialize callback that merges a cached item
+        into it's internal session, which is necessary to share objects
+        across process boundaries"""
+        for op in self.__deserialize_callbacks_per_store.get(store, []):
+            op(obj)
