@@ -227,4 +227,12 @@ class SqlAlchemyStore(BaseStore):
     def _sa_batch_get(self, klass, keys):
         # FIXME: this is very inefficient, need to read up on the SA API a bit more
         return [self.get(klass, k) for k in keys]
+        
+    def _before_stockpyle_deserialize(self, obj):
+        """this callback is used by ChainedStore to post-process any
+        object that was deserialized out of another Store. As documented
+        in the SQLAlchemy API, we should use the merge() operation with
+        dont_load=True for handling deserialized SA objects"""
+        
+        self.__session.merge(obj, dont_load=True)
         
\ No newline at end of file
