@@ -3,7 +3,7 @@ try:
     __HAVE_SA = True
 except ImportError:
     import sys
-    print >> sys.stderr, "\n*** warning: skipping optional SQLAlchemy tests, you don't have the module (http://pypi.python.org/pypi/SQLAlchemy)"
+    print >> sys.stderr, "WARNING: skipping optional SQLAlchemy tests, missing module 'SQLAlchemy' (http://pypi.python.org/pypi/SQLAlchemy)"
     __HAVE_SA = False
 
 
